# mpservice

Model serving with multiprocessing and batching.

Although the code talks about 'model', the use case is generic.

Reference: [Service Batching from Scratch, Again](https://zpz.github.io/blog/batched-service-redesign/)